@@ -16,7 +16,7 @@ from django.core.exceptions import SuspiciousOperation
 from django.db import transaction
 from django.urls import reverse
 
-from .conf import settings as oidc_rp_settings
+from .conf.settings import dynamic_setting as oidc_rp_settings
 from .models import OIDCUser
 from .utils import validate_and_return_id_token, get_logger, build_absolute_uri
 from .decorator import ssl_verification
