@@ -185,3 +185,138 @@ IGNORE_SSL_VERIFICATION = getattr(
 ALWAYS_UPDATE_USER = getattr(
     settings, 'AUTH_OPENID_ALWAYS_UPDATE_USER', True
 )
+
+
+class DynamicSetting(object):
+
+    @property
+    def PROVIDER_ENDPOINT(self):
+        return getattr(settings, 'AUTH_OPENID_PROVIDER_ENDPOINT', 'https://example.com/a/')
+
+    @property
+    def PROVIDER_URL(self):
+        parsed_provider_endpoint = urlparse(self.PROVIDER_ENDPOINT)
+        return '{}://{}'.format(parsed_provider_endpoint.scheme, parsed_provider_endpoint.netloc)
+
+    @property
+    def PROVIDER_AUTHORIZATION_ENDPOINT(self):
+        return getattr(settings, 'AUTH_OPENID_PROVIDER_AUTHORIZATION_ENDPOINT', urljoin(self.PROVIDER_ENDPOINT, 'authorize'))
+
+    @property
+    def PROVIDER_TOKEN_ENDPOINT(self):
+        return getattr(settings, 'AUTH_OPENID_PROVIDER_TOKEN_ENDPOINT', urljoin(self.PROVIDER_ENDPOINT, 'token'))
+
+    @property
+    def PROVIDER_JWKS_ENDPOINT(self):
+        return getattr(settings, 'AUTH_OPENID_PROVIDER_JWKS_ENDPOINT', urljoin(self.PROVIDER_ENDPOINT, 'jwks'))
+
+    @property
+    def PROVIDER_USERINFO_ENDPOINT(self):
+        return getattr(settings, 'AUTH_OPENID_PROVIDER_USERINFO_ENDPOINT', urljoin(self.PROVIDER_ENDPOINT, 'userinfo'))
+
+    @property
+    def PROVIDER_END_SESSION_ENDPOINT(self):
+        return getattr(settings, 'AUTH_OPENID_PROVIDER_END_SESSION_ENDPOINT', None)
+
+    @property
+    def PROVIDER_END_SESSION_REDIRECT_URI_PARAMETER(self):
+        return getattr(settings, 'AUTH_OPENID_PROVIDER_END_SESSION_REDIRECT_URI_PARAMETER', 'post_logout_redirect_uri')
+
+    @property
+    def PROVIDER_END_SESSION_ID_TOKEN_PARAMETER(self):
+        return getattr(settings, 'AUTH_OPENID_PROVIDER_END_SESSION_ID_TOKEN_PARAMETER', 'id_token_hint')
+
+    @property
+    def PROVIDER_SIGNATURE_ALG(self):
+        return getattr(settings, 'AUTH_OPENID_PROVIDER_SIGNATURE_ALG', 'HS256')
+
+    @property
+    def PROVIDER_SIGNATURE_KEY(self):
+        return getattr(settings, 'AUTH_OPENID_PROVIDER_SIGNATURE_KEY', None)
+
+    @property
+    def CLIENT_ID(self):
+        return getattr(settings, 'AUTH_OPENID_CLIENT_ID', None)
+
+    @property
+    def CLIENT_SECRET(self):
+        return getattr(settings, 'AUTH_OPENID_CLIENT_SECRET', None)
+
+    @property
+    def USE_STATE(self):
+        return getattr(settings, 'AUTH_OPENID_USE_STATE', True)
+
+    @property
+    def STATE_LENGTH(self):
+        return getattr(settings, 'AUTH_OPENID_STATE_LENGTH', 32)
+
+    @property
+    def SCOPES(self):
+        return getattr(settings, 'AUTH_OPENID_SCOPES', 'openid email')
+
+    @property
+    def USE_NONCE(self):
+        return getattr(settings, 'AUTH_OPENID_USE_NONCE', True)
+
+    @property
+    def NONCE_LENGTH(self):
+        return getattr(settings, 'AUTH_OPENID_NONCE_LENGTH', 32)
+
+    @property
+    def ID_TOKEN_MAX_AGE(self):
+        return getattr(settings, 'AUTH_OPENID_ID_TOKEN_MAX_AGE', 600)
+
+    @property
+    def ID_TOKEN_INCLUDE_CLAIMS(self):
+        return getattr(settings, 'AUTH_OPENID_ID_TOKEN_INCLUDE_CLAIMS', False)
+
+    @property
+    def AUTHENTICATION_REDIRECT_URI(self):
+        return getattr(settings, 'AUTH_OPENID_AUTHENTICATION_REDIRECT_URI', '/')
+
+    @property
+    def AUTHENTICATION_FAILURE_REDIRECT_URI(self):
+        return getattr(settings, 'AUTH_OPENID_AUTHENTICATION_FAILURE_REDIRECT_URI', '/')
+
+    @property
+    def USER_DETAILS_HANDLER(self):
+        return getattr(settings, 'AUTH_OPENID_USER_DETAILS_HANDLER', None)
+
+    @property
+    def UNAUTHENTICATED_SESSION_MANAGEMENT_KEY(self):
+        return getattr(settings, 'AUTH_OPENID_UNAUTHENTICATED_SESSION_MANAGEMENT_KEY', None)
+
+    @property
+    def AUTH_OPENID(self):
+        return getattr(settings, 'AUTH_OPENID', False)
+
+    @property
+    def BASE_SITE_URL(self):
+        return getattr(settings, 'BASE_SITE_URL', None)
+
+    @property
+    def AUTH_LOGIN_URL_NAME(self):
+        return getattr(settings, 'AUTH_OPENID_AUTH_LOGIN_URL_NAME', None)
+
+    @property
+    def AUTH_LOGIN_CALLBACK_URL_NAME(self):
+        return getattr(settings, 'AUTH_OPENID_AUTH_LOGIN_CALLBACK_URL_NAME', None)
+
+    @property
+    def AUTH_LOGOUT_URL_NAME(self):
+        return getattr(settings, 'AUTH_OPENID_AUTH_LOGOUT_URL_NAME', None)
+
+    @property
+    def SHARE_SESSION(self):
+        return getattr(settings, 'AUTH_OPENID_SHARE_SESSION', True)
+
+    @property
+    def IGNORE_SSL_VERIFICATION(self):
+        return getattr(settings, 'AUTH_OPENID_IGNORE_SSL_VERIFICATION', True)
+
+    @property
+    def ALWAYS_UPDATE_USER(self):
+        return getattr(settings, 'AUTH_OPENID_ALWAYS_UPDATE_USER', True)
+
+
+dynamic_setting = DynamicSetting()
