@@ -11,7 +11,7 @@ from hashlib import md5, sha224, sha256
 
 from django.contrib.sites.requests import RequestSite
 
-from .conf import settings as oidc_rp_settings
+from .conf.settings import dynamic_setting as oidc_rp_settings
 
 
 _anonymous_session_state = None
