@@ -20,7 +20,7 @@ from django.utils.crypto import get_random_string
 from django.utils.http import is_safe_url, urlencode
 from django.views.generic import View
 
-from .conf import settings as oidc_rp_settings
+from .conf.settings import dynamic_setting as oidc_rp_settings
 from .utils import get_logger, build_absolute_uri
 
 
